from setuptools import setup

setup(name='distributions_up',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['distributions_up'],
      author = 'Jose Ceron',
      author_email = 'jceronrodriguez10@gmail.com',
      zip_safe=False)
